==> sight_20.0.0.orig.tar.gz: sight-20.0.0/libs/visu/fwVTKQml/src/fwVTKQml/VtkRenderWindowInteractorManager.cpp <==
/************************************************************************
 *
 * Copyright (C) 2018 IRCAD France
 * Copyright (C) 2018 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "fwVTKQml/VtkRenderWindowInteractorManager.hpp"

#include <fwRenderVTK/registry/macros.hpp>

#include <vtkRenderer.h>
#include <vtkRenderWindow.h>
#include <vtkRenderWindowInteractor.h>

//-----------------------------------------------------------------------------

fwRenderVTKRegisterMacro( ::fwVTKQml::VtkRenderWindowInteractorManager,
                          ::fwRenderVTK::IVtkRenderWindowInteractorManager::REGISTRY_KEY );

//-----------------------------------------------------------------------------

namespace fwVTKQml
{

//-----------------------------------------------------------------------------

VtkRenderWindowInteractorManager::VtkRenderWindowInteractorManager(
    ::fwRenderVTK::IVtkRenderWindowInteractorManager::Key )
{
}

//-----------------------------------------------------------------------------

VtkRenderWindowInteractorManager::~VtkRenderWindowInteractorManager()
{
}

//-----------------------------------------------------------------------------

void VtkRenderWindowInteractorManager::installInteractor( ::fwGui::container::fwContainer::sptr )
{

}

//-----------------------------------------------------------------------------

void VtkRenderWindowInteractorManager::uninstallInteractor()
{

}

//-----------------------------------------------------------------------------

vtkRenderWindowInteractor* VtkRenderWindowInteractorManager::getInteractor()
{
    OSLM_ASSERT("FrameBuffer is not defined", m_frameBufferItem);
    OSLM_ASSERT("RenderWindow is not defined", m_frameBufferItem->getRenderWindow());
    return m_frameBufferItem->getRenderWindow()->GetInteractor();
}

//-----------------------------------------------------------------------------

void VtkRenderWindowInteractorManager::setFrameBuffer(QPointer< ::fwVTKQml::FrameBufferItem > frameBuffer )
{
    m_frameBufferItem = frameBuffer;
}

//-----------------------------------------------------------------------------

} // namespace fwVTKQml

==> sight_20.2.0.orig.tar.gz: sight-20.2.0/libs/visu/fwVTKQml/src/fwVTKQml/VtkRenderWindowInteractorManager.cpp <==
/************************************************************************
 *
 * Copyright (C) 2018-2020 IRCAD France
 * Copyright (C) 2018-2020 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "fwVTKQml/VtkRenderWindowInteractorManager.hpp"

#include <fwRenderVTK/registry/macros.hpp>

#include <vtkRenderer.h>
#include <vtkRenderWindow.h>
#include <vtkRenderWindowInteractor.h>

//-----------------------------------------------------------------------------

fwRenderVTKRegisterMacro( ::fwVTKQml::VtkRenderWindowInteractorManager,
                          ::fwRenderVTK::IVtkRenderWindowInteractorManager::REGISTRY_KEY );

//-----------------------------------------------------------------------------

namespace fwVTKQml
{

//-----------------------------------------------------------------------------

VtkRenderWindowInteractorManager::VtkRenderWindowInteractorManager(
    ::fwRenderVTK::IVtkRenderWindowInteractorManager::Key )
{
}

//-----------------------------------------------------------------------------

VtkRenderWindowInteractorManager::~VtkRenderWindowInteractorManager()
{
}

//-----------------------------------------------------------------------------

void VtkRenderWindowInteractorManager::installInteractor( ::fwGui::container::fwContainer::sptr )
{

}

//-----------------------------------------------------------------------------

void VtkRenderWindowInteractorManager::uninstallInteractor()
{

}

//-----------------------------------------------------------------------------

vtkRenderWindowInteractor* VtkRenderWindowInteractorManager::getInteractor()
{
    SLM_ASSERT("FrameBuffer is not defined", m_frameBufferItem);
    SLM_ASSERT("RenderWindow is not defined", m_frameBufferItem->getRenderWindow());
    return m_frameBufferItem->getRenderWindow()->GetInteractor();
}

//-----------------------------------------------------------------------------

void VtkRenderWindowInteractorManager::setFrameBuffer(QPointer< ::fwVTKQml::FrameBufferItem > frameBuffer )
{
    m_frameBufferItem = frameBuffer;
}

//-----------------------------------------------------------------------------

} // namespace fwVTKQml
